==> Module-CPANTS-Site-0.60.tar.gz: Module-CPANTS-Site-0.60/script/module_cpants_site_create.pl <==
#!/usr/local/bin/perl -w

use strict;
use Getopt::Long;
use Pod::Usage;
use Catalyst::Helper;

my $force = 0;
my $help  = 0;

GetOptions(
    'nonew|force' => \$force,
    'help|?'      => \$help
 );

pod2usage(1) if ( $help || !$ARGV[0] );

my $helper = Catalyst::Helper->new( { '.newfiles' => !$force } );

pod2usage(1) unless $helper->mk_component( 'Module::CPANTS::Site', @ARGV );

1;

=head1 NAME

module_cpants_site_create.pl - Create a new Catalyst Component

=head1 SYNOPSIS

module_cpants_site_create.pl [options] model|view|controller name [helper] [options]

 Options:
   -force    don't create a .new file where a file to be created exists
   -help     display this help and exits

 Examples:
   module_cpants_site_create.pl controller My::Controller
   module_cpants_site_create.pl view My::View
   module_cpants_site_create.pl view MyView TT
   module_cpants_site_create.pl view TT TT
   module_cpants_site_create.pl model My::Model
   module_cpants_site_create.pl model SomeDB CDBI dbi:SQLite:/tmp/my.db
   module_cpants_site_create.pl model AnotherDB CDBI dbi:Pg:dbname=foo root 4321

 See also:
   perldoc Catalyst::Manual
   perldoc Catalyst::Manual::Intro

=head1 DESCRIPTION

Create a new Catalyst Component.

Existing component files are not overwritten.  If any of the component files
to be created already exist the file will be written with a '.new' suffix.
This behavior can be suppressed with the C<-force> option.

=head1 AUTHOR

Sebastian Riedel, C<sri@oook.de>

=head1 COPYRIGHT

Copyright 2004 Sebastian Riedel. All rights reserved.

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

==> Module-CPANTS-Site-0.63.tar.gz: Module-CPANTS-Site-0.63/script/module_cpants_site_create.pl <==
#!/usr/bin/perl -w

use strict;
use warnings;
use Getopt::Long;
use Pod::Usage;
use Catalyst::Helper;

my $force = 0;
my $mech  = 0;
my $help  = 0;

GetOptions(
    'nonew|force'    => \$force,
    'mech|mechanize' => \$mech,
    'help|?'         => \$help
 );

pod2usage(1) if ( $help || !$ARGV[0] );

my $helper = Catalyst::Helper->new( { '.newfiles' => !$force, mech => $mech } );

pod2usage(1) unless $helper->mk_component( 'Module::CPANTS::Site', @ARGV );

1;

=head1 NAME

module_cpants_site_create.pl - Create a new Catalyst Component

=head1 SYNOPSIS

module_cpants_site_create.pl [options] model|view|controller name [helper] [options]

 Options:
   -force        don't create a .new file where a file to be created exists
   -mechanize    use Test::WWW::Mechanize::Catalyst for tests if available
   -help         display this help and exits

 Examples:
   module_cpants_site_create.pl controller My::Controller
   module_cpants_site_create.pl -mechanize controller My::Controller
   module_cpants_site_create.pl view My::View
   module_cpants_site_create.pl view MyView TT
   module_cpants_site_create.pl view TT TT
   module_cpants_site_create.pl model My::Model
   module_cpants_site_create.pl model SomeDB DBIC::Schema MyApp::Schema create=dynamic\
   dbi:SQLite:/tmp/my.db
   module_cpants_site_create.pl model AnotherDB DBIC::Schema MyApp::Schema create=static\
   dbi:Pg:dbname=foo root 4321

 See also:
   perldoc Catalyst::Manual
   perldoc Catalyst::Manual::Intro

=head1 DESCRIPTION

Create a new Catalyst Component.

Existing component files are not overwritten.  If any of the component files
to be created already exist the file will be written with a '.new' suffix.
This behavior can be suppressed with the C<-force> option.

=head1 AUTHOR

Sebastian Riedel, C<sri@oook.de>
Maintained by the Catalyst Core Team.

=head1 COPYRIGHT

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
